# PSQF 6243 Example 2 using R

# Set width of output and  number of digits to be printed
options("width"=120, "digits"=8) 

# Use this to turn off scientific notation: 
# "fixed notation will be preferred unless it is more than 'scipen' digits wide"
options(scipen=999)

if (!require("readxl")) install.packages("readxl")
library(readxl) # To import excel XLSX data with labels as table

if (!require("expss")) install.packages("expss")
library(expss) # To add variable and value labels, sorting

if (!require("psych")) install.packages("psych")
library(psych) # To add descriptive summary functions

if (!require("multcomp")) install.packages("multcomp")
library(multcomp) # To do glht linear combinations in GLMs

if (!require("TeachingDemos")) install.packages("TeachingDemos")
library(TeachingDemos) # To create text output files using code below


################################################################################
#####            BEGIN EXAMPLE 2 DATA IMPORT AND MANIPULATION              #####
################################################################################

# Set working directory (to import and export files to)
# Paste in the folder address where "GSS_Example.xlsx" is saved in quotes
setwd("C:/Dropbox/22SP_PSQF6243/PSQF6243_Example2")

# Import GSS_Example.xlsx data from working directory -- path = file name
Example2 = read_excel(path="GSS_Example.xlsx", sheet="GSS_Example") 
# Convert to data frame to use for analysis
Example2 = as.data.frame(Example2)

# Label variables used below (add descriptive titles) using comments instead
#   because variable labels are not allowed in many analysis packages
# Format: name = Descriptive Variable Label
# marry  = marry: Marital Status (1=unmarried, 2=married)
# educ   = educ: Years of Education
# income = income: Annual Income in 1000s

# Open external file to save results to
txtStart(file="Example2_R_Output.txt")


################################################################################
#####                BEGIN EXAMPLE 2 DATA DESCRIPTION                      #####
################################################################################

# describe prints sample descriptive statistics for quantitative variables
# list variables to be included in separate quotes within c concatenate function
print("R Descriptive Statistics for Quantitative or Binary Variables")
describe(x=Example2[ , c("income","educ","marry")])

# Get variances too (on diagonal of output matrix)
var(x=Example2[ , c("income","educ","marry")])

txtComment(" ") # insert blank space in output


################################################################################
#####             BEGIN EXAMPLE 2 GENERAL LINEAR MODELS                    #####
################################################################################

print("R Empty GLM Predicting Income -- save as ModelEmpty")
ModelEmpty = lm(data=Example2, formula=income~1) # 1 represents intercept
anova(ModelEmpty)   # anova to print residual variance
summary(ModelEmpty) # summary to print fixed effects solution 
confint.lm(ModelEmpty, level=.95) # confint to print level% CI for fixed effects

txtComment(" ") # insert blank space in output


####### MODELS WITH QUANTITATIVE EDUCATION AS A PREDICTOR #######

print("R GLM Predicting Income from Original Education -- save as ModelEduc")
ModelEduc = lm(data=Example2, formula=income~1+educ)
anova(ModelEduc)   # anova to print residual variance
summary(ModelEduc) # summary to print fixed effects solution 
confint.lm(ModelEduc, level=.95) # confint.lm to print level% CI for fixed effects

txtComment(" ") # insert blank space in output

# Center education predictor so that 0 is meaningful
Example2$educ12 = Example2$educ-12
# educ12: Education (0=12 years)

print("R GLM Predicting Income from Centered Education 0=12 -- save as ModelEduc12")
ModelEduc12 = lm(data=Example2, formula=income~1+educ12)
anova(ModelEduc12)   # anova to print residual variance
summary(ModelEduc12) # summary to print fixed effects solution
confint.lm(ModelEduc12, level=.95) # confint.lm to print level% CI for fixed effects

print("R Demonstrating how to get predicted outcomes using glht -- save as PredEduc12")
print("In number lists below, values are multiplier for each fixed effect in order")
PredEduc12 = glht(model=ModelEduc12, linfct=rbind(
  "Pred Income for  8 years (educ12=-4)" = c(1,-4),  
  "Pred Income for 12 years (educ12= 0)" = c(1, 0), 
  "Pred Income for 16 years (educ12= 4)" = c(1, 4), 
  "Pred Income for 20 years (educ12= 8)" = c(1, 8)))
print("Print glht linear combination results with unadjusted p-values")
summary(PredEduc12, test=adjusted("none")) 
confint(PredEduc12, level=.95, calpha=univariate_calpha())

print("R GLM Predicting Income using Standardized Solution -- save as ModelEducSTD")
print("scale () standardizes each variable as M=0 SD=1 z-score for analysis")
ModelEducSTD = lm(data=Example2, formula=scale(income)~1+scale(educ12))
summary(ModelEducSTD) # print standardized fixed effect solution 

txtComment(" ") # insert blank space in output


####### MODELS WITH BINARY MARITAL STATUS AS A PREDICTOR #######

# Recode marry predictor so that 0 is meaningful
Example2$marry01=NA  # Create new empty variable, then recode 
Example2$marry01[which(Example2$marry==1)]=0 
Example2$marry01[which(Example2$marry==2)]=1
# marry01: 0=unmarried, 1=married 

print("R GLM Predicting Income from Marry01 (0=Unmarried,1=Married) -- save as ModelMarry01")
ModelMarry01 = lm(data=Example2, formula=income~1+marry01)
anova(ModelMarry01)   # anova to print residual variance
summary(ModelMarry01) # summary to print fixed effects solution
confint.lm(ModelMarry01, level=.95) # confint.lm to print level% CI for fixed effects

print("R Demonstrating how to get predicted outcomes using glht -- save as PredMarry01")
print("In number lists below, values are multiplier for each fixed effect in order")
PredMarry01 = glht(model=ModelMarry01, linfct=rbind(
  "Pred Income for Unmarried=0" = c(1,0),  
  "Pred income for Married=1"   = c(1,1)))
print("Print glht linear combination results with unadjusted p-values")
summary(PredMarry01, test=adjusted("none")) 
confint(PredMarry01, level=.95, calpha=univariate_calpha())

print("R Compute d effect size for marry01 from t test-statistic")
CohenD = 2*6.25/sqrt(732)
print(CohenD)

txtComment(" ") # insert blank space in output


################################################################################
#####             BEGIN EXAMPLE 2 PEARSON CORRELATIONS                     #####
################################################################################


print("R Pearson Correlation Matrix")
cor(x=cbind(Example2$income,Example2$educ,Example2$marry), method="pearson") 
print("R Pearson Correlation Pairwise Significance tests and CIs")
cor.test(x=Example2$income, y=Example2$educ,  method="pearson", conf.level=.95) 
cor.test(x=Example2$income, y=Example2$marry, method="pearson", conf.level=.95) 
cor.test(x=Example2$educ,   y=Example2$marry, method="pearson", conf.level=.95) 


# Close output text file
txtStop()

