// Prevent "more" messages from appearing
set more off
// Control line length
set linesize 150

********************************************************************************
*******       BEGIN EXAMPLE 2 DATA IMPORT AND MANIPULATION               *******
********************************************************************************

// Paste in the folder address where "GSS_Example.xlsx" is saved between " "
cd "C:\Dropbox\22SP_PSQF6243\PSQF6243_Example2"
// Using the UIowa virtual desktop instead, it would look like this
// cd "\\Client\C:\Dropbox\22SP_PSQF6243\PSQF6243_Example2"

// Import GSS_Example.xlsx data from working directory using exact file name
// To change all variable names to lowercase, remove "case(preserve")
clear // Clear before means close any open data
import excel "GSS_Example.xlsx", case(preserve) firstrow clear 
// Clear after means re-import if it already exists (need to start over)

// Label variables used below
// label variable name "name: Descriptive Variable Label"   
label variable marry   "marry: Marital Status (1=unmarried, 2=married)"
label variable educ    "educ: Years of Education"
label variable income  "income: Annual Income in 1000s"

// Select cases complete on variables to be used
egen nmiss = rowmiss(income educ marry)
drop if nmiss>0

// Now dataset is ready to use

// Example of sorting to find specific case for slides
sort educ income

// Open external text file to save results to
log using Example2_STATA_Output.log, replace 


********************************************************************************
******              BEGIN EXAMPLE 2 DATA DESCRIPTION                     *******
********************************************************************************

display "STATA Descriptive Statistics for Quantitative or Binary Variables"
summarize income educ marry, detail


********************************************************************************
******             BEGIN EXAMPLE 2 GENERAL LINEAR MODELS                 *******
********************************************************************************

display "STATA Empty GLM Predicting Income"
regress income, level(95)  // level gives (95)% CI

////// MODELS WITH QUANTITATIVE EDUCATION AS A PREDICTOR //////

display "STATA GLM Predicting Income from Original Education"
regress income educ, level(95)  

// Center education predictor so that 0 is meaningful
gen educ12=educ-12
label variable educ12 "educ12: Education (0=12 years)"

display "STATA GLM Predicting Income from Centered Education (0=12)"
regress income educ12, level(95)  // with 95% CI for unstandardized solution
// In LINCOMs below, _cons is intercept, words refer to the beta fixed effect,
// and values are the multiplier for the requested predictor value
lincom _cons*1 + educ12*-4  // Pred Income for  8 years (educ12=-4)
lincom _cons*1 + educ12*0   // Pred Income for 12 years (educ12= 0)
lincom _cons*1 + educ12*4   // Pred Income for 16 years (educ12= 4)
lincom _cons*1 + educ12*8   // Pred Income for 18 years (educ12= 8)

/*
display "STATA GLM Predicting Income from Centered Education (0=12)"
regress income educ12, beta  // beta gives standardized solution

display "STATA Regression Line with CI for mean (stdp option)"
graph twoway lfitci income educ12, stdp || scatter income educ12

display "STATA Regression Line with CI for individual (stdf option)"
graph twoway lfitci income educ12, stdf || scatter income educ12
*/

////// MODELS WITH BINARY MARITAL STATUS AS A PREDICTOR //////

// Recode marry predictor so that 0 is meaningful
gen marry01=. // Create new empty variable, then recode
replace marry01=0 if marry==1
replace marry01=1 if marry==2
label variable marry01 "marry01: 0=unmarried, 1=married"

display "STATA GLM Predict Income from Marry01 (0=Unmarried,1=Married)"
regress income marry01, level(95) // with 95% CI for unstandardized solution 
// LINCOMs below request predicted outcome means for each category
lincom _cons*1 + marry01*0 // Pred Income for Unmarried=0 = Beta0  
lincom _cons*1 + marry01*1 // Pred Income for Married=1   = Beta0 + Beta1 

display "STATA Compute Cohen's D from t test-statistic"
display 2*6.25/sqrt(732)

********************************************************************************
******             BEGIN EXAMPLE 2 PEARSON CORRELATIONS                  *******
********************************************************************************

display "STATA Pearson Correlations and CIs" 
pwcorr income educ marry, sig
// To get CI using r-to-z, need to download and run a special module
ssc install ci2
ci2 income educ, corr
ci2 income marry, corr
ci2 educ marry, corr

// Close external output file
log close  
     
       
       



